@@ -189,8 +189,11 @@ the layout to the selected layout-name."
        (error "Not on a channel"))
      (list (completing-read
 	    "User: "
-	    (mapcar #'list (riece-channel-get-users
-			    riece-current-channel)))
+	    (mapcar #'list
+		    (riece-with-server-buffer
+			(riece-identity-server riece-current-channel)
+		      (riece-channel-get-users
+		       (riece-identity-prefix riece-current-channel)))))
 	   (if current-prefix-arg
 	       (read-string "Message: ")))))
   (riece-send-string
@@ -238,7 +241,7 @@ the layout to the selected layout-name."
 	    (if (and riece-current-channel
 		     (riece-channel-p (riece-identity-prefix
 				       riece-current-channel)))
-		(cons (riece-format-identity riece-current-channel t)
+		(cons (riece-identity-prefix riece-current-channel)
 		      0))))))
   (if (or (not (equal pattern ""))
 	  (yes-or-no-p "Really want to query LIST without argument? "))
