@@ -105,7 +105,8 @@ way is to put Riece variables on .emacs or file loaded from there."
 			  riece-guess
 			  riece-unread
 			  riece-history
-			  riece-url)
+			  riece-url
+			  riece-button)
   "Add-ons insinuated into Riece."
   :type '(repeat symbol)
   :group 'riece-options)
