@@ -207,11 +207,16 @@ the `riece-server-keyword-map' variable."
 	    (throw 'found t))
 	(setq process-list (cdr process-list))))))
 
+(eval-when-compile
+  (autoload 'riece-exit "riece"))
 (defun riece-quit-server-process (process &optional message)
   (run-at-time riece-quit-timeout nil
 	       (lambda (process)
-		 (if (memq process riece-process-list)
-		     (kill-process (process-buffer process))))
+		 (when (memq process riece-process-list)
+		   (riece-close-server-process process)
+		   ;; If no server process is available, exit.
+		   (unless riece-process-list
+		     (riece-exit))))
 	       process)
   (riece-process-send-string process
 			     (if message
